@@ -1,19 +1,19 @@
+import logging
 from typing import Any, Callable, Dict, List, Sequence, Type, TypeVar, Union
+
 import numpy
 import numpy as np
-from numpy import (
-    logical_not as not_,
-    maximum as max_,
-    minimum as min_,
-    round as round_,
-    select,
-    where,
-)
 import pandas as pd
-import logging
-from policyengine_core.types import ArrayLike, ArrayType
-from policyengine_core.populations.population import Population
+from numpy import logical_not as not_
+from numpy import maximum as max_
+from numpy import minimum as min_
+from numpy import round as round_
+from numpy import select, where
+
+from policyengine_core.parameters.parameter_node import ParameterNode
 from policyengine_core.periods.period_ import Period
+from policyengine_core.populations.population import Population
+from policyengine_core.types import ArrayLike, ArrayType
 from policyengine_core.variables.variable import Variable
 
 T = TypeVar("T")
@@ -92,13 +92,11 @@ def concat(this: ArrayLike[str], that: ArrayLike[str]) -> ArrayType[str]:
     if isinstance(this, numpy.ndarray) and not numpy.issubdtype(
         this.dtype, numpy.str_
     ):
-
         this = this.astype("str")
 
     if isinstance(that, numpy.ndarray) and not numpy.issubdtype(
         that.dtype, numpy.str_
     ):
-
         that = that.astype("str")
 
     return numpy.char.add(this, that)
@@ -227,31 +225,6 @@ def add(
     )
 
 
-def aggr(entity, period, variables, options=None):
-    """Sums a list of variables belonging to entity members.
-
-    Args:
-        entity (Population): The entity population, as passed in formulas.
-        period (Period): The period, as pass in formulas.
-        variables (List[str]): A list of variable names.
-        options (List[str], optional): Options to pass to the `entity(variable, period)` call. Defaults to None.
-
-    Raises:
-        ValueError: If any target variable is not below the target entity level.
-
-    Returns:
-        ArrayLike: The result of the operation.
-    """
-    return for_each_variable(
-        entity,
-        period,
-        variables,
-        agg_func="add",
-        group_agg_func="add",
-        options=options,
-    )
-
-
 def and_(
     entity: Population,
     period: Period,
@@ -324,6 +297,9 @@ def amount_between(
 
 
 def random(entity, reset=True):
+    if entity.simulation.has_axes:
+        # Don't simulate randomness in simulations with axes.
+        return 0
     if reset:
         np.random.seed(0)
     x = np.random.rand(entity.count)
@@ -434,3 +410,38 @@ def sum_of_variables(variables: Union[List[str], str]) -> Callable:
 
 
 any_of_variables = sum_of_variables
+
+
+def index_(
+    into: ParameterNode,
+    indices: Union[ArrayLike, List[ArrayLike]],
+    where: ArrayLike,
+    fill: float = 0,
+) -> ArrayLike:
+    """Indexes into a object, but only when a condition is true. This improves
+    performance over `np.where`, which will index all values and then filter the result.
+
+    Args:
+        into (Parameter): The parameter to index into.
+        indices (Union[ArrayLike, List[ArrayLike]]): The full, un-filtered index array. Can be a list of arrays
+            for sequential indexing.
+        where (ArrayLike): A filter for indexing.
+        fill (float, optional): The value to fill where `index_where` is False. Defaults to 0.
+
+    Returns:
+        ArrayLike: The indexed result.
+    """
+    if where.sum() == 0:
+        return np.ones(where.shape) * fill
+
+    if isinstance(indices, list):
+        result = np.empty_like(indices[0])
+        intermediate_result = into
+        for i in range(len(indices)):
+            intermediate_result = intermediate_result[indices[i][where]]
+        result[where] = intermediate_result
+    else:
+        result = np.empty_like(indices)
+        result[where] = into[indices[where]]
+    result[~where] = fill
+    return result.astype(float)
