@@ -178,7 +178,10 @@ class Simulation:
         builder = SimulationBuilder()
         builder.populations = self.populations
         try:
-            data = self.dataset.load(self.dataset_year)
+            try:
+                data = self.dataset.load(self.dataset_year)
+            except:
+                data = self.dataset.load()
         except FileNotFoundError as e:
             raise FileNotFoundError(
                 f"The dataset file {self.dataset.name} (with year {self.dataset_year}) could not be found. "
@@ -436,6 +439,8 @@ class Simulation:
         Returns:
             ArrayLike: The calculated variable.
         """
+        if variable_name not in self.tax_benefit_system.variables:
+            raise ValueError(f"Variable {variable_name} does not exist.")
         population = self.get_variable_population(variable_name)
         holder = population.get_holder(variable_name)
         variable = self.tax_benefit_system.get_variable(
@@ -444,6 +449,15 @@ class Simulation:
 
         self._check_period_consistency(period, variable)
 
+        # Check if we've neutralized via parameters.
+        try:
+            if self.tax_benefit_system.parameters(period).gov.abolitions[
+                variable.name
+            ]:
+                return holder.default_array()
+        except Exception as e:
+            pass
+
         # First look for a value already cached
         cached_array = holder.get_array(period, self.branch_name)
         if cached_array is not None:
@@ -544,7 +558,7 @@ class Simulation:
         # We wait for the end of calculate(), signalled by an empty stack, before purging the cache
         if self.tracer.stack:
             return
-        for (_name, _period) in self.invalidated_caches:
+        for _name, _period in self.invalidated_caches:
             holder = self.get_holder(_name)
             holder.delete_arrays(_period)
         self.invalidated_caches = set()
@@ -644,13 +658,6 @@ class Simulation:
 
         return variable.calculate_output(self, variable_name, period)
 
-    def trace_parameters_at_instant(self, formula_period):
-        return TracingParameterNodeAtInstant(
-            self.tax_benefit_system.get_parameters_at_instant(formula_period),
-            self.tracer,
-            self.branch_name,
-        )
-
     def _run_formula(
         self, variable: str, population: Population, period: Period
     ) -> ArrayLike:
@@ -702,10 +709,14 @@ class Simulation:
                     )
             return values
 
-        if self.trace:
-            parameters_at = self.trace_parameters_at_instant
-        else:
-            parameters_at = self.tax_benefit_system.get_parameters_at_instant
+        if self.trace and not isinstance(
+            self.tax_benefit_system.parameters, TracingParameterNodeAtInstant
+        ):
+            # Soft-recast
+            self.tax_benefit_system.parameters.branch_name = self.branch_name
+            self.tax_benefit_system.parameters.trace = True
+            self.tax_benefit_system.parameters.tracer = self.tracer
+        parameters_at = self.tax_benefit_system.parameters
 
         if formula.__code__.co_argcount == 2:
             array = formula(population, period)
@@ -966,7 +977,12 @@ class Simulation:
             for population in self.populations.values()
         }
 
-    def clone(self, debug: bool = False, trace: bool = False) -> "Simulation":
+    def clone(
+        self,
+        debug: bool = False,
+        trace: bool = False,
+        clone_tax_benefit_system: bool = True,
+    ) -> "Simulation":
         """
         Copy the simulation just enough to be able to run the copy without modifying the original simulation
         """
@@ -988,26 +1004,32 @@ class Simulation:
             setattr(
                 new, entity.key, population
             )  # create shortcut simulation.household (for instance)
-
-        new.tax_benefit_system = self.tax_benefit_system.clone()
+        if clone_tax_benefit_system:
+            new.tax_benefit_system = self.tax_benefit_system.clone()
+        else:
+            new.tax_benefit_system = self.tax_benefit_system
         new.debug = debug
         new.trace = trace
 
         return new
 
-    def get_branch(self, name: str = "branch") -> "Simulation":
+    def get_branch(
+        self, name: str = "branch", clone_system: bool = False
+    ) -> "Simulation":
         """Create a clone of this simulation, whose calculations are traced in the original.
 
         Args:
             name (str, optional): Name of the branch. Defaults to "branch".
-            store (bool, optional): Whether to store the branch in the original simulation. Defaults to True.
+            clone_system (bool, optional): Whether to clone the tax-benefit system. Use this if you're changing policy parameters. Defaults to False.
 
         Returns:
             Simulation: The cloned simulation.
         """
         if name == self.branch_name:
             return self
-        branch = self.clone()
+        if name in self.branches:
+            return self.branches[name]
+        branch = self.clone(clone_tax_benefit_system=clone_system)
         self.branches[name] = branch
         branch.branch_name = name
         if self.trace:
