@@ -4,6 +4,4 @@ from .full_tracer import FullTracer
 from .performance_log import PerformanceLog
 from .simple_tracer import SimpleTracer
 from .trace_node import TraceNode
-from .tracing_parameter_node_at_instant import (
-    TracingParameterNodeAtInstant,
-)
+from .tracing_parameter_node_at_instant import TracingParameterNodeAtInstant
